# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from public_api_server_connector.models.quiz_questions_inner import QuizQuestionsInner

class ModuleLessonPatchQuizQuestions(BaseModel):
    """
    ModuleLessonPatchQuizQuestions
    """
    quiz_questions: conlist(QuizQuestionsInner) = Field(default=..., description="Questions with ID are updated, questions without ID are created. Existing questions not in the list are kept. Within each question, answers follow the same rule: with ID = update/keep, without ID = create, absent = delete.")
    __properties = ["quiz_questions"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ModuleLessonPatchQuizQuestions:
        """Create an instance of ModuleLessonPatchQuizQuestions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in quiz_questions (list)
        _items = []
        if self.quiz_questions:
            for _item in self.quiz_questions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['quiz_questions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ModuleLessonPatchQuizQuestions:
        """Create an instance of ModuleLessonPatchQuizQuestions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ModuleLessonPatchQuizQuestions.parse_obj(obj)

        _obj = ModuleLessonPatchQuizQuestions.parse_obj({
            "quiz_questions": [QuizQuestionsInner.from_dict(_item) for _item in obj.get("quiz_questions")] if obj.get("quiz_questions") is not None else None
        })
        return _obj


