# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from public_api_server_connector.models.ipn_transaction import IpnTransaction

class IpnOrderRefund(BaseModel):
    """
    IpnOrderRefund
    """
    id: StrictStr = Field(default=..., description="External id of the original order to refund, as it was provided or returned on the /ipn/payment call (without the portal id prefix)")
    transaction: Optional[IpnTransaction] = Field(default=None, description="Refund transaction information, including amount and external id")
    __properties = ["id", "transaction"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IpnOrderRefund:
        """Create an instance of IpnOrderRefund from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IpnOrderRefund:
        """Create an instance of IpnOrderRefund from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IpnOrderRefund.parse_obj(obj)

        _obj = IpnOrderRefund.parse_obj({
            "id": obj.get("id"),
            "transaction": IpnTransaction.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None
        })
        return _obj


